@@ -5,8 +5,8 @@
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; Created: 31 Oct 2009
-;; Package-Version: 2.90.2
-;; Package-Revision: a131a553f48d
+;; Package-Version: 20251024.2344
+;; Package-Revision: da577c6f5ac0
 ;; Keywords: text, pandoc
 ;; URL: http://joostkremers.github.io/pandoc-mode/
 
@@ -892,7 +892,7 @@ file exists, display the *Pandoc output* buffer."
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (defun pandoc--read-completion-function (formats)
-  "Create a completion function for `pandoc-set-read-from-category' for FORMATS.
+  "Create a completion function for `pandoc-set-read' for FORMATS.
 Return a function that can be used in `completing-read' as the
 COLLECTION function, using TABLE as the completion table."
   (lambda (str pred flag)
@@ -904,7 +904,7 @@ COLLECTION function, using TABLE as the completion table."
                                                          'face 'italic))))
       (complete-with-action flag formats str pred))))
 
-(defun pandoc-set-read-from-category (category)
+(defun pandoc-set-read (category)
   "Set the input format.
 CATEGORY is a string naming a category of formats as listed in
 `pandoc--formats'.  Only formats from CATEGORY are offered as completion
@@ -914,14 +914,6 @@ candidates."
     (pandoc--set 'read format)
     (message "Input format set to `%s'" format)))
 
-(defun pandoc-set-read (format)
-  "Set the input format to FORMAT."
-  (interactive (list (completing-read "Set input format to: "
-                                      (pandoc--extract-formats 'input)
-                                      nil t)))
-  (pandoc--set 'read format)
-  (message "Input format set to `%s'" format))
-
 (defun pandoc-set-write (format)
   "Set the output format to FORMAT.
 If a settings and/or project file exists for FORMAT, they are
@@ -1266,8 +1258,7 @@ argument, the option is toggled."
                                                         (key (nth 2 format-spec)))
                                                     (list key description (lambda ()
                                                                             (interactive)
-                                                                            (pandoc-set-read format-name))
-                                                          :transient t)))
+                                                                            (pandoc-set-read format-name)))))
                                                (seq-filter (lambda (elt)
                                                              (not (eq (nth 3 elt) 'output)))
                                                            (drop 3 (quote ,group))))
@@ -1295,8 +1286,7 @@ argument, the option is toggled."
                                                         (key (nth 2 format-spec)))
                                                     (list key description (lambda ()
                                                                             (interactive)
-                                                                            (pandoc-set-write format-name))
-                                                          :transient t)))
+                                                                            (pandoc-set-write format-name)))))
                                                (seq-filter (lambda (elt)
                                                              (not (eq (nth 3 elt) 'input)))
                                                            (drop 3 (quote ,group))))
